Developing Betty itself - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Developing Betty itself

This section covers how to develop Betty itself.

See also

Read Contributing to Betty before sharing your improvements to Betty with the wider community.

## In this section

- Install a Betty development environment.

- Testing Betty’s source code

- Localization

- Helpful commands